@@ -98,7 +98,7 @@ void create_list(
 void destroy_list(
 	struct plist	**list)		/* pointer to list pointer */
 {
-	register int	i;		/* entry counter */
+	int		i;		/* entry counter */
 
 	if (!*list)
 		return;
@@ -118,9 +118,9 @@ void destroy_list(
  */
 
 static int sort_same_time(
-	register struct entry	*entry,		/* changed entry */
-	struct plist		*list,		/* list to adjust */
-	int			n)		/* index to proposed new pos */
+	struct entry	*entry,		/* changed entry */
+	struct plist	*list,		/* list to adjust */
+	int		n)		/* index to proposed new pos */
 {
 	while (n > 0 && list->entry[n-1].time == entry->time
 		     && list->entry[n-1].seq > entry->seq)
@@ -152,8 +152,8 @@ int add_entry(
 	struct plist		*new;		/* larger list if required */
 	struct lookup		lookup;		/* result of entry lookup */
 	int			n;		/* index of new entry in list*/
-	register struct entry	*p, *q;		/* entry copy pointers */
-	register int		i;		/* entry copy counter */
+	struct entry		*p, *q;		/* entry copy pointers */
+	int			i;		/* entry copy counter */
 	static unsigned int	next_seq;	/* next entry->seq number */
 
 	if (*list) {
@@ -207,11 +207,11 @@ int add_entry(
  */
 
 void delete_entry(
-	struct plist		*list,		/* list to delete from */
-	int			n)		/* index to entry to delete */
+	struct plist	*list,		/* list to delete from */
+	int		n)		/* index to entry to delete */
 {
-	register struct entry	*q;		/* entry copy pointer */
-	register int		i;		/* entry copy counter */
+	struct entry	*q;		/* entry copy pointer */
+	int		i;		/* entry copy counter */
 
 	list->locked++;
 	if (n < 0 || n >= list->nentries) {
@@ -237,17 +237,18 @@ void delete_entry(
  */
 
 void delete_entry_by_id(
-	struct plist		*list,		/* list to delete from */
-	unsigned int		file,		/* file ID from server */
-	int			id)		/* row ID from server */
+	struct plist	*list,		/* list to delete from */
+	unsigned int	file,		/* file ID from server */
+	int		id)		/* row ID from server */
 {
-	register struct entry	*ep;		/* entry search pointer */
-	register int		n;		/* entry search counter */
+	struct entry	*ep;		/* entry search pointer */
+	int		n;		/* entry search counter */
 
 	list->locked++;
 	for (ep=list->entry, n=0; n < list->nentries; n++, ep++)
 		if (ep->file == file && ep->id == id) {
 			delete_entry(list, n);
+			list->locked--;
 			return;
 		}
 	list->locked--;
@@ -262,14 +263,14 @@ void delete_entry_by_id(
  */
 
 int resort_entry(
-	struct plist		*list,		/* list to re-sort */
-	int			n)		/* index to changed entry */
+	struct plist	*list,		/* list to re-sort */
+	int		n)		/* index to changed entry */
 {
-	struct lookup		lookup;		/* result of entry lookup */
-	register struct entry	*p;		/* entry copy pointer */
-	register int		i;		/* entry copy counter */
-	struct entry		save;		/* to save changed entry */
-	int			d;		/* new destination index */
+	struct lookup	lookup;		/* result of entry lookup */
+	struct entry	*p;		/* entry copy pointer */
+	int		i;		/* entry copy counter */
+	struct entry	save;		/* to save changed entry */
+	int		d;		/* new destination index */
 
 	list->locked++;
 	if (n < 0 || n >= list->nentries) {
@@ -316,11 +317,11 @@ int resort_entry(
  */
 
 void rebuild_repeat_chain(
-	struct plist		*list)		/* list to delete from */
+	struct plist	*list)		/* list to delete from */
 {
-	register int		*prev;		/* previous chain pointer */
-	register struct entry	*ep;		/* scan pointer */
-	register int		n;		/* entry counter */
+	int		*prev;		/* previous chain pointer */
+	struct entry	*ep;		/* scan pointer */
+	int		n;		/* entry counter */
 
 	if (list) {
 		list->locked++;
@@ -360,17 +361,17 @@ static int lookup_regular_entry  (struct plist *, time_t, BOOL, BOOL);
 static int lookup_repeating_entry(struct plist *, time_t, BOOL, time_t *,
 							char, int, BOOL *);
 BOOL lookup_entry(
-	register struct lookup	*lookup,	/* return struct */
-	register struct plist	*list,		/* list of entries */
-	time_t			time,		/* time to locate */
-	BOOL			exact,		/* need entry, not insert pt */
-	BOOL			norep,		/* ignore instances */
-	char			which,		/* 'mywod': mon,yr,wk,yov,day*/
-	int			usr)		/* user number or -1 */
+	struct lookup	*lookup,	/* return struct */
+	struct plist	*list,		/* list of entries */
+	time_t		time,		/* time to locate */
+	BOOL		exact,		/* need entry, not insert pt */
+	BOOL		norep,		/* ignore instances */
+	char		which,		/* 'mywod': mon,yr,wk,yov,day*/
+	int		usr)		/* user number or -1 */
 {
-	int			repindex, regindex;
-	time_t			reptime = -1, regtime = -1;
-	BOOL			warn = 0;
+	int		repindex, regindex;
+	time_t		reptime = -1, regtime = -1;
+	BOOL		warn = 0;
 
 	list->locked++;
 	lookup->regindex  = lookup->repindex = -1;
@@ -400,13 +401,13 @@ BOOL lookup_entry(
 
 
 static int lookup_regular_entry(
-	struct plist		*list,		/* list of entries */
-	time_t			time,		/* time to locate */
-	BOOL			exact,		/* need entry, not insert pt */
-	BOOL			norep)		/* treat repeaters as regular*/
+	struct plist	*list,		/* list of entries */
+	time_t		time,		/* time to locate */
+	BOOL		exact,		/* need entry, not insert pt */
+	BOOL		norep)		/* treat repeaters as regular*/
 {
-	register struct entry	*entry;		/* entry array */
-	register int		lo, hi, mid;	/* binary search indices */
+	struct entry	*entry;		/* entry array */
+	int		lo, hi, mid;	/* binary search indices */
 
 	entry = list->entry;
 	lo = 0;
@@ -435,42 +436,42 @@ static int lookup_regular_entry(
 
 
 static int lookup_repeating_entry(
-	struct plist		*list,		/* list of entries */
-	time_t			time,		/* time to locate */
-	BOOL			exact,		/* need entry, not insert pt */
-	time_t			*reptime,	/* returned repeat time */
-	char			which,		/* 'mywd': month,yr,week,day */
-	int			usr,		/* user number or -1 */
-	BOOL			*warn)		/* found a n-days-ahead warn?*/
+	struct plist	*list,		/* list of entries */
+	time_t		time,		/* time to locate */
+	BOOL		exact,		/* need entry, not insert pt */
+	time_t		*reptime,	/* returned repeat time */
+	char		which,		/* 'mywd': month,yr,week,day */
+	int		usr,		/* user number or -1 */
+	BOOL		*warn)		/* found a n-days-ahead warn?*/
 {
-	register struct entry	*entry;		/* entry array */
-	register int		n, i;		/* next repeating entry */
-	register time_t		earliest = 0;	/* earliest future entry yet */
-	register int		earliest_n= -1;	/* index of that entry */
-	BOOL			earliest_w = 0;	/* is it a n-days-ahead warn?*/
-	int			prev_n = -1;	/* entry before n */
-	int			earliest_prev_n=-1;/* entry before earliest_n*/
-	time_t			test;		/* next repeater trigger */
+	struct entry	*entry;		/* entry array */
+	int		n, i;		/* next repeating entry */
+	time_t		earliest = 0;	/* earliest future entry yet */
+	int		earliest_n= -1;	/* index of that entry */
+	BOOL		earliest_w = 0;	/* is it a n-days-ahead warn?*/
+	int		prev_n = -1;	/* entry before n */
+	int		earliest_prev_n=-1;/* entry before earliest_n*/
+	time_t		test;		/* next repeater trigger */
 
 	exact = exact != FALSE;
 	for (n=list->repeating; n != -1; prev_n=n, n=entry->nextrep) {
 		entry = &list->entry[n];
 		if (which != '*') {
 			int u = name_to_user(entry->user);
-			if (which == 'm' && user[u].suspend_m ||
-			    which == 'w' && user[u].suspend_w ||
-			    which == 'o' && user[u].suspend_o ||
-			    which == 'd' && user[u].suspend_d)
+			if ((which == 'm' && user[u].suspend_m) ||
+			    (which == 'w' && user[u].suspend_w) ||
+			    (which == 'o' && user[u].suspend_o) ||
+			    (which == 'd' && user[u].suspend_d))
 				continue;
 		}
-		if (which == 'm' && entry->hide_in_m ||
-		    which == 'y' && entry->hide_in_y ||
-		    which == 'w' && entry->hide_in_w ||
-		    which == 'o' && entry->hide_in_o ||
-		    which == 'd' && entry->hide_in_d)
+		if ((which == 'm' && entry->hide_in_m) ||
+		    (which == 'y' && entry->hide_in_y) ||
+		    (which == 'w' && entry->hide_in_w) ||
+		    (which == 'o' && entry->hide_in_o) ||
+		    (which == 'd' && entry->hide_in_d))
 			continue;
 
-		if (usr >= 0 && (usr && !entry->user ||
+		if (usr >= 0 && ((usr && !entry->user) ||
 				 strcmp(user[usr].name, entry->user)))
 			continue;
 
@@ -507,19 +508,19 @@ static int lookup_repeating_entry(
  */
 
 BOOL lookup_next_entry(
-	register struct lookup	*lookup)	/* previously found entry */
+	struct lookup	*lookup)	/* previously found entry */
 {
-	register struct entry	*entry;		/* entry array */
-	register int		n, i;		/* next repeating entry */
-	int			repindex = -1, regindex = -1;
-	time_t			reptime, regtime = 0;
-	struct plist		*list = lookup->list;
-	time_t			time = 0;
-	int			prev_n, earliest_prev_n = -1;
-	register time_t		earliest = 0;
-	register int		earliest_n = -1;
-	BOOL			earliest_w = 0;
-	int			u;
+	struct entry	*entry;		/* entry array */
+	int		n, i;		/* next repeating entry */
+	int		repindex = -1, regindex = -1;
+	time_t		reptime, regtime = 0;
+	struct plist	*list = lookup->list;
+	time_t		time = 0;
+	int		prev_n, earliest_prev_n = -1;
+	time_t		earliest = 0;
+	int		earliest_n = -1;
+	BOOL		earliest_w = 0;
+	int		u;
 
 							/* next repeating */
 	prev_n = lookup->repindex >= 0 ? lookup->repindex
@@ -535,18 +536,18 @@ BOOL lookup_next_entry(
 	for (; n != -1; prev_n=n, n=entry->nextrep) {
 		entry = &list->entry[n];
 		u = name_to_user(entry->user);
-		if (lookup->which != '*' &&
-		   (lookup->which == 'm' && user[u].suspend_m ||
-		    lookup->which == 'w' && user[u].suspend_w ||
-		    lookup->which == 'o' && user[u].suspend_o ||
-		    lookup->which == 'd' && user[u].suspend_d))
+		if ( lookup->which != '*' &&
+		   ((lookup->which == 'm' && user[u].suspend_m) ||
+		    (lookup->which == 'w' && user[u].suspend_w) ||
+		    (lookup->which == 'o' && user[u].suspend_o) ||
+		    (lookup->which == 'd' && user[u].suspend_d)))
 			continue;
 
-		if (lookup->which == 'm' && entry->hide_in_m ||
-		    lookup->which == 'y' && entry->hide_in_y ||
-		    lookup->which == 'w' && entry->hide_in_w ||
-		    lookup->which == 'o' && entry->hide_in_o ||
-		    lookup->which == 'd' && entry->hide_in_d)
+		if ((lookup->which == 'm' && entry->hide_in_m) ||
+		    (lookup->which == 'y' && entry->hide_in_y) ||
+		    (lookup->which == 'w' && entry->hide_in_w) ||
+		    (lookup->which == 'o' && entry->hide_in_o) ||
+		    (lookup->which == 'd' && entry->hide_in_d))
 			continue;
 
 		if (lookup->user >= 0 && lookup->user != u)
@@ -632,20 +633,20 @@ BOOL lookup_next_entry(
  */
 
 int find_next_trigger(
-	struct plist		*list,		/* list of entries */
-	time_t			time,		/* time to locate */
-	struct entry		**entryp,	/* ret: entry that was found */
-	time_t			*wait_time)	/* ret: how long until triggr*/
+	struct plist	*list,		/* list of entries */
+	time_t		time,		/* time to locate */
+	struct entry	**entryp,	/* ret: entry that was found */
+	time_t		*wait_time)	/* ret: how long until triggr*/
 {
-	BOOL			found;		/* TRUE if lookup succeeded */
-	struct lookup		lookup;		/* result of entry lookup */
-	register struct entry	*ep;		/* current entry */
-	time_t			trigger;	/* next trigger time of *ep */
-	time_t			dist, t;	/* time distance to event */
-	time_t			mindist = MAXT;	/* smallest distance so far */
-	int			i;		/* for checking exceptions */
-	int			u;		/* user[] index */
-	int			reason = 0;	/* why is it earliest: 1,2,3 */
+	BOOL		found;		/* TRUE if lookup succeeded */
+	struct lookup	lookup;		/* result of entry lookup */
+	struct entry	*ep;		/* current entry */
+	time_t		trigger;	/* next trigger time of *ep */
+	time_t		dist, t;	/* time distance to event */
+	time_t		mindist = MAXT;	/* smallest distance so far */
+	int		i;		/* for checking exceptions */
+	int		u;		/* user[] index */
+	int		reason = 0;	/* why is it earliest: 1,2,3 */
 
 	if (!list)
 		return(0);
@@ -724,11 +725,11 @@ int find_next_trigger(
  */
 
 void clone_entry(
-	register struct entry	*new,		/* entry to fill in */
-	register struct entry	*old)		/* entry to clone, or 0 */
+	struct entry	*new,		/* entry to fill in */
+	struct entry	*old)		/* entry to clone, or 0 */
 {
 	if (!old) {					/* zero new entry */
-		register int i;
+		unsigned int i;
 		for (i=0; i < sizeof(struct entry); i++)
 			((char *)new)[i] = 0;
 		return;
@@ -751,7 +752,7 @@ void clone_entry(
  */
 
 void destroy_entry(
-	register struct entry	*entry)		/* entry to destroy */
+	struct entry	*entry)		/* entry to destroy */
 {
 	if (entry->user)
 		free(entry->user);
